%define subver 1.9
%define abiver 1.9.1
%define rubyver 1.9.3
%define patchversion p194

Summary:	Object Oriented Script Language
Name:		ruby
Version:	%{rubyver}.%{patchversion}
Release: 	2
License:	Ruby or GPLv2
Group:		Development/Ruby

Source0:	ftp://ftp.ruby-lang.org/pub/ruby/%{subver}/ruby-%{rubyver}-%{patchversion}.tar.bz2
Source1:	http://www.rubycentral.com/faq/rubyfaqall.html
Source2:	http://dev.rubycentral.com/downloads/files/ProgrammingRuby-0.4.tar.bz2
# from ruby 1.9, to prevent file conflicts
Source4:	ruby-mode.el
Patch1:		ruby-do-not-use-system-ruby-to-generate-ri-doc.patch
Patch3:		ruby-do_not_propagate_no-undefined.patch
Patch4:		ruby-1.8.7-gnueabi.patch
# http://redmine.ruby-lang.org/issues/5108
Patch5:		ruby-1.8.7-p352-stdout-rouge-fix.patch
# Use shared libs as opposed to static for mkmf
# See bug rhbz#428384
Patch6:		ruby-1.8.7-p249-mkmf-use-shared.patch
URL:		http://www.ruby-lang.org/

BuildRequires:	autoconf
BuildRequires:	byacc
BuildRequires:	ncurses-devel
BuildRequires:	readline-devel
BuildRequires:	tcl-devel tk-devel
BuildRequires:	db5-devel
BuildRequires:	libgdbm-devel >= 1.8.3
BuildRequires:	openssl-devel
BuildRequires:	zlib-devel
BuildRequires:	yaml-devel
%rename		ruby-rexml
%rename		ruby-irb
%rename		ruby-libs
%rename		ruby-rdoc
%rename		ruby1.9
%rename		ruby-rake
%rename		rubygem-rake
Provides:	rubygem(rake) = 0.9.2.2
%rename		ruby-RubyGems
Provides:	rubygems = %version-%release

# explicit file provides (since such requires are automatically added by find-requires)
Provides:	/usr/bin/ruby
Provides:	ruby(abi) = %{abiver}
# will also apply to all subpackages also, but since they all depend on
# ruby = %version anyways for now, it doesn't really matter...
%if %{_use_internal_dependency_generator}
%define __noautoreq		'ruby\\(abi\\)'
%else
%define _requires_exceptions	ruby\(abi\)
%endif

%define my_target_cpu %{_target_cpu}
%ifarch ppc
%define my_target_cpu powerpc
%endif
%ifarch ppc64
%define my_target_cpu powerpc64
%endif
%ifarch amd64
%define my_target_cpu x86_64
%endif

%define	libname	%mklibname ruby %{subver}

%package -n	%{libname}
Summary:	Shared main library for ruby %{subver}
Group:		System/Libraries

%package	doc
Summary:	Documentation for the powerful language Ruby
Group:		Development/Ruby
BuildArch:	noarch
%rename		ruby1.9-doc

%package	devel
Summary:	Development file for the powerful language Ruby
Group:		Development/Ruby
Requires:	%{name} = %{version}
%rename		ruby-static
%rename		ruby1.9-devel

%package	tk
Summary:	Tk extension for the powerful language Ruby
Group:		Development/Ruby
Requires:	%{name} = %{version}
%rename		ruby1.9-tk

%description
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl).  It is simple, straight-forward, and extensible.

%description -n	%{libname}
This package contains the shared ruby %{subver} library.

%description	doc
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl). It is simple, straight-forward, and extensible.

This package contains the Ruby's documentation

%description	devel
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl). It is simple, straight-forward, and extensible.

This package contains the Ruby's devel files.

%description	tk
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl). It is simple, straight-forward, and extensible.

This package contains the Tk extension for Ruby.

%prep
%setup -q -n ruby-%{rubyver}-%{patchversion}
%patch1 -p1 -b .ri
%patch3 -p1 -b .undefined
%ifarch %arm
%patch4 -p1
%endif
%patch5 -p1 -b .stdout~
%patch6 -p1 -b .shared~

autoreconf

%build
CFLAGS=`echo %optflags | sed 's/-fomit-frame-pointer//'`
%configure2_5x	--enable-shared \
		--disable-rpath \
		--enable-pthread \
		--with-sitedir=%{_prefix}/lib/ruby/%{abiver}/site_ruby \
		--with-vendordir=%{_prefix}/lib/ruby/%{abiver}/vendor_ruby \
		--with-rubylibprefix=%{_prefix}/lib/ruby
%make

%install
%makeinstall_std install-doc

install -d %{buildroot}%{_docdir}/%{name}-%{version}
cp -a COPYING* ChangeLog README* ToDo sample %{buildroot}%{_docdir}/%{name}-%{version}
install -m644 %{SOURCE1} -D %{buildroot}%{_docdir}/%{name}-%{version}/FAQ.html

install -m644 %{SOURCE4} -D %{buildroot}%{_datadir}/emacs/site-lisp/ruby-mode.el

install -d %{buildroot}%{_sysconfdir}/emacs/site-start.d
cat <<EOF >%{buildroot}%{_sysconfdir}/emacs/site-start.d/%{name}.el
(autoload 'ruby-mode "ruby-mode" "Ruby editing mode." t)
(add-to-list 'auto-mode-alist '("\\\\.rb$" . ruby-mode))
(add-to-list 'interpreter-mode-alist '("ruby" . ruby-mode))
EOF

tar -C %{buildroot}%{_docdir}/%{name}-%{version} -xjf %{SOURCE2}
mv %{buildroot}%{_docdir}/%{name}-%{version}/ProgrammingRuby-*/{html/*,}
rm -rf %{buildroot}%{_docdir}/%{name}-%{version}/ProgrammingRuby-*/{html,xml}/

# Make the file/dirs list, filtering out tcl/tk and devel files
find %{buildroot}%{_prefix}/lib/ruby/%{abiver} \
          \( -not -type d -printf "%%p\n" \) \
          -or \( -type d -printf "%%%%dir %%p\n" \) \
| sed -e 's#%{buildroot}##g' \
| egrep -v '/(tcl)?tk|(%{my_target_cpu}-%{_target_os}/.*[ha]$)' > %{name}.list

# Fix scripts permissions and location
find %{buildroot} sample -type f | file -i -f - | grep text | cut -d: -f1 >text.list
cat text.list | xargs chmod 0644
#  Magic grepping to get only files with '#!' in the first line
cat text.list | xargs grep -n '^#!' | grep ':1:#!' | cut -d: -f1 >shebang.list
cat shebang.list | xargs sed -i -e 's|/usr/local/bin|/usr/bin|; s|\./ruby|/usr/bin/ruby|'
cat shebang.list | xargs chmod 0755

%check
make test

%files -f %{name}.list
%dir %{_docdir}/%{name}-%{version}
%doc %{_docdir}/%{name}-%{version}/README
%doc %{_docdir}/%name
%{_bindir}/*
%dir %{_prefix}/lib/%{name}/
%{_mandir}/*/*
%{_datadir}/emacs/site-lisp/*
%dir %_prefix/lib/%name/gems/%abiver/gems
%dir %_prefix/lib/%name/gems/%abiver/gems/rake-*
%dir %_prefix/lib/%name/gems/%abiver/gems/rake-*/bin
%{_prefix}/lib/%{name}/gems/%{abiver}/gems/rake-*/bin/rake
%dir %{_prefix}/lib/%{name}/gems/%{abiver}/gems/rdoc-*
%dir %{_prefix}/lib/%{name}/gems/%{abiver}/gems/rdoc-*/bin
%{_prefix}/lib/%{name}/gems/%{abiver}/gems/rdoc-*/bin/rdoc
%{_prefix}/lib/%{name}/gems/%{abiver}/gems/rdoc-*/bin/ri
%dir %_prefix/lib/%name/gems/%abiver/specifications
%{_prefix}/lib/%{name}/gems/%{abiver}/specifications/*.gemspec
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*

%files -n %{libname}
%{_libdir}/libruby.so.%{subver}*

%files doc
%{_datadir}/ri
%dir %{_docdir}/%{name}-%{version}
%{_docdir}/%{name}-%{version}/COPYING*
%{_docdir}/%{name}-%{version}/ChangeLog
%{_docdir}/%{name}-%{version}/README.*
%{_docdir}/%{name}-%{version}/FAQ.html
%{_docdir}/%{name}-%{version}/ToDo
%{_docdir}/%{name}-%{version}/sample
%{_docdir}/%{name}-%{version}/ProgrammingRuby*

%files devel
%{_includedir}/ruby-*
%{_libdir}/libruby-static.a
%{_libdir}/libruby.so
%{_libdir}/pkgconfig/ruby-%{subver}.pc

%files tk
%{_prefix}/lib/%{name}/%{abiver}/%{my_target_cpu}-%{_target_os}/tcltk*
%{_prefix}/lib/%{name}/%{abiver}/%{my_target_cpu}-%{_target_os}/tk*
%{_prefix}/lib/%{name}/%{abiver}/tcltk*
%{_prefix}/lib/%{name}/%{abiver}/tk*


%changelog
* Wed May 16 2012 Bernhard Rosenkraenzer <bero@bero.eu> 1.9.3.p194-2
+ Revision: 799161
- Obsolete ruby-RubyGems, it's part of ruby in 1.9.x

* Fri Apr 20 2012 Bernhard Rosenkraenzer <bero@bero.eu> 1.9.3.p194-1
+ Revision: 792560
- Update to 1.9.3-p194
- Fix directory ownership

  + Dmitry Mikhirev <dmikhirev@mandriva.org>
    - rebuild to fix provides

* Wed Feb 15 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.9.3.p0-6
+ Revision: 774476
- obsolete ruby1.9 subpackages as well

* Wed Feb 15 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.9.3.p0-5
+ Revision: 774436
- add a provides for rubygem(rake) to satisfy gem dependencies

* Wed Feb 15 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.9.3.p0-4
+ Revision: 774422
- obsolete rake, it's now part of ruby standard library...

* Sat Feb 11 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.9.3.p0-3
+ Revision: 773368
- obsolete ruby1.9 package

* Fri Feb 10 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.9.3.p0-2
+ Revision: 772514
- build with libyaml support

* Mon Jan 23 2012 Bernhard Rosenkraenzer <bero@bero.eu> 1.9.3.p0-1
+ Revision: 767037
- Update to 1.9.3-p0

* Sat Oct 15 2011 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.8.7.p352-3
+ Revision: 704761
- don't run commands in sub-shells as their return value won't be checked
- don't compress rubyfaqall.html, leave it to rpm payload compression...
- ditch tcl/tk versioned library test, it's not likely to be of relevance anymore
- make 'ruby-doc' sub-package noarch
- fix upgrades from previous butched ruby releases..
- move around dependencies in spec for easier readability
- ditch shipping our own set of macros as these are provided by rpm now
- separate shared library into separate package per library packaging policies
- clean out some legacy rpm junk
- use shared libs as opposed to static for mkmf (P6 from Fedora, rhbz#428384)
- fix stdout redirection issue with glibc >= 2.14, breaking generated code (P5)
- update and simplify lib64 patch
- revert reckless import of fedora package

  + Paulo Andrade <pcpa@mandriva.com.br>
    - Simplify arm build by not removing gnu from substring from target_os

* Thu Sep 08 2011 Andrey Smirnov <asmirnov@mandriva.org> 1.8.7.p352-2
+ Revision: 699006
- libdir fix

* Wed Sep 07 2011 Andrey Smirnov <asmirnov@mandriva.org> 1.8.7.p352-1
+ Revision: 698627
- rpmlint warning

  + Alexander Barakin <abarakin@mandriva.org>
    - imported package ruby

* Mon Jun 20 2011 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.8.7.p334-4
+ Revision: 686286
- avoid dependencies on ruby(abi) provided by itself
- fix file conflicts on emacs ruby editing mode file with ruby1.9 package

* Thu May 05 2011 Oden Eriksson <oeriksson@mandriva.com> 1.8.7.p334-3
+ Revision: 669456
- mass rebuild

* Thu Mar 31 2011 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.8.7.p334-2
+ Revision: 649361
- rebuild against berkeley db 5.1

* Sun Feb 20 2011 Rémy Clouard <shikamaru@mandriva.org> 1.8.7.p334-1
+ Revision: 638832
- new patchset 334, fix vulnerability in FileUtils#remove_entry_secure

* Sun Dec 26 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p330-1mdv2011.0
+ Revision: 625126
- new version 1.8.7-p330

* Sun Dec 19 2010 Rémy Clouard <shikamaru@mandriva.org> 1.8.7.p302-3mdv2011.0
+ Revision: 623192
- add ruby(abi) provides

* Wed Dec 01 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p302-2mdv2011.0
+ Revision: 604336
- rebuild for new zlib

* Fri Aug 20 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p302-1mdv2011.0
+ Revision: 571401
- new version 1.8.7 p302

* Fri Jul 09 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p299-1mdv2011.0
+ Revision: 549887
- New version 1.8.7-p299 (drop merged patches)

* Fri Jun 18 2010 Pascal Terjan <pterjan@mandriva.org> 1.8.7.p249-4mdv2010.1
+ Revision: 548298
- Own doc dir in -doc package too, so that it gets removed (#59831)

* Mon Apr 05 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p249-3mdv2010.1
+ Revision: 531719
- add arch patch to build with openssl 1.0.0
- rebuild for new openssl

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 1.8.7.p249-2mdv2010.1
+ Revision: 511635
- rebuilt against openssl-0.9.8m

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - fix annoying '`*' interpreted as argument prefix' warning with pathname (P4)

* Sun Jan 10 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p249-1mdv2010.1
+ Revision: 488839
- new patch series p249

* Sun Jan 03 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p248-1mdv2010.1
+ Revision: 486008
- 1.8.7-p248
- move patchversion into version tag, so that releases become real releases

* Fri Jan 01 2010 Oden Eriksson <oeriksson@mandriva.com> 1.8.7-10p174mdv2010.1
+ Revision: 484729
- rebuilt against bdb 4.8

* Tue Jun 16 2009 Frederik Himpe <fhimpe@mandriva.org> 1.8.7-9p174mdv2010.0
+ Revision: 386433
- Update to new version 1.8.7-p174

* Sat Jun 13 2009 Frederik Himpe <fhimpe@mandriva.org> 1.8.7-9p173mdv2010.0
+ Revision: 385730
- Update to new version 1.8.7-p173

* Tue May 12 2009 Frederik Himpe <fhimpe@mandriva.org> 1.8.7-9p160mdv2010.0
+ Revision: 374964
- Update to version 1.8.7-p160 (fixes CVE-2007-1558 and CVE-2008-1447)
- Remove patch for compilation with gcc 4.3: integrated upstream

* Thu Feb 26 2009 Pascal Terjan <pterjan@mandriva.org> 1.8.7-9p72mdv2009.1
+ Revision: 345172
- Rediff lib64 patch

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild for new libreadline

* Sat Dec 06 2008 Adam Williamson <awilliamson@mandriva.org> 1.8.7-8p72mdv2009.1
+ Revision: 311085
- rebuild for new tcl

* Thu Sep 11 2008 Pixel <pixel@mandriva.com> 1.8.7-7p72mdv2009.0
+ Revision: 283683
- explicitly provide /usr/bin/ruby
  (since such requires are automatically added by find-requires) (#42316)

* Wed Aug 13 2008 Frederik Himpe <fhimpe@mandriva.org> 1.8.7-6p72mdv2009.0
+ Revision: 271536
- Update ruby 1.8.7 to patchlevel 72 (fixes CVE-2008-1447,
  CVE-2008-3655, CVE-2008-3656, CVE-2008-3657)
- Remove CVE-2008-2376 patch: fix integrated upstream

* Thu Jul 10 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.7-5p22mdv2009.0
+ Revision: 233280
- 1.8.7-p22
  . security fixes for CVE-2008-2662, CVE-2008-2663, CVE-2008-2664,
    CVE-2008-2725, CVE-2008-2726
- P4: fix for CVE-2008-2376

* Tue Jun 10 2008 Pascal Terjan <pterjan@mandriva.org> 1.8.7-4p17mdv2009.0
+ Revision: 217724
- Filter -Wl,--no-undefined from CFLAGS used by mkmf

* Tue Jun 10 2008 Pascal Terjan <pterjan@mandriva.org> 1.8.7-3p17mdv2009.0
+ Revision: 217392
- Really fix archdir on x86_64

* Tue Jun 10 2008 Pascal Terjan <pterjan@mandriva.org> 1.8.7-2p17mdv2009.0
+ Revision: 217351
- Fix archdir on x86_64

* Tue Jun 10 2008 Pascal Terjan <pterjan@mandriva.org> 1.8.7-1p17mdv2009.0
+ Revision: 217304
- Add macros ruby_vendorarchdir and ruby_vendorlibdir
- Update to p17

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon Jun 09 2008 Pascal Terjan <pterjan@mandriva.org> 1.8.7-1mdv2009.0
+ Revision: 217004
- Enforce vendor_ruby in /usr/lib
- Add linux-gnu to search path
- 1.8.7
- Drop P2 and P26
- Update P0
- Enforce sitedir to be in /usr/lib

* Fri May 23 2008 Oden Eriksson <oeriksson@mandriva.com> 1.8.6-12p114mdv2009.0
+ Revision: 210416
- bump release

* Fri May 23 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.6-11p114mdv2009.0
+ Revision: 210214
- added ruby-1.8.6p114-mdv,svn-tk85-gcc43.patch: fix tk extension build for
  tcl/tk 8.5, required with GCC 4.3
- fixed use of host_os, which should be target_os, in files lists

  + Oden Eriksson <oeriksson@mandriva.com>
    - added a gcc43 patch from fedora

* Mon Mar 10 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.6-9p114mdv2008.1
+ Revision: 183218
- new patch version p114
- Patch3 (ruby-1.8.6-p111-rexml-trans) applied upstream
- made the patch version visible in the Release tag
- fixed License tag following policy

* Fri Feb 22 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.6-8mdv2008.1
+ Revision: 173813
- fixes a variable name in REXML code, pointed by Guillaume Cottenceau

* Mon Jan 28 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.6-7mdv2008.1
+ Revision: 159036
- updated to ruby-1.8.6-p111 (fixes CVE-2007-5162)
- removed Patch2 (ruby-rdoc_graphviz), fixed upstream a little differently
- removed Patch3 (rexml-double-encoding), applied upstream
- Patch2 (CVE-2007-5770 fix), from Suse, minus CVE-2007-5162 fixes; ruby
  1.8.6 doesn't seem to have SSL support in smtp.rb and pop.rb
- -doc subpackage doesn't requires main package

* Fri Dec 21 2007 Oden Eriksson <oeriksson@mandriva.com> 1.8.6-6mdv2008.1
+ Revision: 136344
- rebuilt against new build deps

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Sep 07 2007 Anssi Hannula <anssi@mandriva.org> 1.8.6-5mdv2008.0
+ Revision: 82045
- rebuild for new soname of tcl

* Thu Jun 07 2007 Guillaume <gc@mandriva.com> 1.8.6-4mdv2008.0
+ Revision: 36514
- add patch3: Fix REXML wrongly saving XML special chars as doubly escaped entities

  + Pascal Terjan <pterjan@mandriva.org>
    - Be more consistant in the macros

  + Nicolas Lécureuil <nlecureuil@mandriva.com>
    - Remove double BR

* Mon Apr 23 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.8.6-3mdv2008.0
+ Revision: 17162
- Fix BuildRequires (tk-devel instead of libx11-devel)

* Sun Apr 22 2007 Pascal Terjan <pterjan@mandriva.org> 1.8.6-2mdv2008.0
+ Revision: 16751
- BuildRequires libx11-devel until tk-devel get fixed
- Use Development/Ruby group
- Fix the dot -V parsing in rdoc for recent graphviz


* Sat Apr 07 2007 Pascal Terjan <pterjan@mandriva.org> 1.8.6-1mdv2007.1
+ Revision: 151012
- 1.8.6
- drop p3 and p4
- uncompress and update p0 and p1

* Mon Dec 18 2006 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.5-5mdv2007.1
+ Revision: 98532
- Mostly build changes:
- dependencies fixes
  . don't need full XFree86-devel, tcl/tk devel packages should be enough
  . add missing zlib1-devel BuildRequires, which before was probably being
    provided indirectly by XFree86-devel
- avoid use of non-ascii chars in spec (parameter separator for sed command)
- avoid implicitly requiring Perl for build (for filtering devel and tk
  files)
- use file lists instead of shell loops for fixing permissions, for shorter
  build time

* Wed Dec 06 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.5-4mdv2007.1
+ Revision: 91863
- CVE-2006-6303

* Mon Oct 30 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.5-3mdv2007.1
+ Revision: 73677
- CVE-2006-5467
- Import ruby

* Tue Sep 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.8.5-2mdv2007.0
- Rebuild

* Sat Aug 26 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.5-1mdv2007.0
- 1.8.5
- Drop P2, P3, P4, P5, P6

* Wed Aug 23 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.4-7mdv2007.0
- CVE-2006-3694 (P4, P5, P6)
- Fix macros in changelog
- Move make test into %%check

* Sun Jul 16 2006 Guillaume Cottenceau 1.8.4-6mdv2007.0
- author patch3 since even ruby authors don't care to ship a badly broken
  rexml for several months

* Sat May 20 2006 Laurent MONTEL <lmontel@mandriva.com> 1.8.4-5
- Add patch2 (patch from opensuse): don't redefine eaccess (it's into new glibc)

* Thu Mar 09 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.4-4mdk
- BuildRequire openssl-devel

* Tue Feb 14 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.4-3mdk
- Move /etc/rpm/ruby.macros to main package. It is required to build a lot
  of noarch package which do not need -devel.

* Thu Feb 09 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.4-2mdk
- Provide /etc/rpm/ruby.macros with usual macros

* Fri Jan 27 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.4-1mdk
- 1.8.4
- Update P0

* Tue Jan 03 2006 Oden Eriksson <oeriksson@mandriva.com> 1.8.3-5mdk
- rebuilt against soname aware deps (tcl/tk)
- fix deps
- enable threading (--enable-pthread)

* Sun Nov 13 2005 Oden Eriksson <oeriksson@mandriva.com> 1.8.3-4mdk
- rebuilt against openssl-0.9.8a

* Fri Nov 04 2005 Michael Scherer <misc@mandriva.org> 1.8.3-3mdk
- mkrel

* Thu Oct 06 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.8.3-2mdk
- ppc64 fixes

* Sat Oct 01 2005 Pascal Terjan <pterjan@mandriva.org> 1.8.3-1mdk
- 1.8.3
- Drop P2
- Update P1
- Fix requires-on-release

* Wed Jul 13 2005 Pascal Terjan <pterjan@mandriva.org> 1.8.2-7mdk
- CAN-2005-1992 (P2)
- Fix interpreter and rights on samples

* Thu Mar 31 2005 Pascal Terjan <pterjan@mandrake.org> 1.8.2-6mdk
- put and search everything in %%{_prefix}/lib/ruby/ even on x86_64, else all
  noarch packages won't work

* Fri Jan 21 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.8.2-5mdk
- rebuild for new readline

* Tue Jan 18 2005 Gtz Waschk <waschk@linux-mandrake.com> 1.8.2-4mdk
- force build with libgdbm3

* Sat Jan 15 2005 Pixel <pixel@mandrakesoft.com> 1.8.2-3mdk
- add ri doc (bugzilla #12976)

* Sun Jan 02 2005 Pascal Terjan <pterjan@mandrake.org> 1.8.2-2mdk
- Disable rpath

* Fri Dec 31 2004 Pascal Terjan <pterjan@mandrake.org> 1.8.2-1mdk
- 1.8.2

* Wed Dec 08 2004 Götz Waschk <waschk@linux-mandrake.com> 1.8.1-5mdk
- rebuild for libgdbm3

* Tue Aug 31 2004 Götz Waschk <waschk@linux-mandrake.com> 1.8.1-4mdk
- build with db 4.2

* Tue Jun 29 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.8.1-2mdk
- BuildRequires: tcl

